@@ -9,7 +9,7 @@ from .jc_types import ParserInfoType, JSONDictType
 from jc import appdirs
 
 
-__version__ = '1.23.3'
+__version__ = '1.23.5'
 
 parsers: List[str] = [
     'acpi',
@@ -43,6 +43,7 @@ parsers: List[str] = [
     'email-address',
     'env',
     'file',
+    'find',
     'findmnt',
     'finger',
     'free',
@@ -57,6 +58,7 @@ parsers: List[str] = [
     'hashsum',
     'hciconfig',
     'history',
+    'host',
     'hosts',
     'id',
     'ifconfig',
@@ -66,6 +68,7 @@ parsers: List[str] = [
     'iostat-s',
     'ip-address',
     'iptables',
+    'ip-route',
     'iso-datetime',
     'iw-scan',
     'iwconfig',
@@ -77,6 +80,7 @@ parsers: List[str] = [
     'ls',
     'ls-s',
     'lsattr',
+    'lsb-release',
     'lsblk',
     'lsmod',
     'lsof',
@@ -89,9 +93,11 @@ parsers: List[str] = [
     'mpstat-s',
     'netstat',
     'nmcli',
+    'nsd-control',
     'ntpq',
     'openvpn',
     'os-prober',
+    'os-release',
     'passwd',
     'pci-ids',
     'pgpass',
@@ -143,6 +149,7 @@ parsers: List[str] = [
     'proc-net-packet',
     'proc-net-protocols',
     'proc-net-route',
+    'proc-net-tcp',
     'proc-net-unix',
     'proc-pid-fdinfo',
     'proc-pid-io',
@@ -154,6 +161,7 @@ parsers: List[str] = [
     'proc-pid-statm',
     'proc-pid-status',
     'ps',
+    'resolve-conf',
     'route',
     'rpm-qi',
     'rsync',
